@@ -211,7 +211,7 @@ class DocParser:
         if document["extension"] in Extension.IMAGE_EXTENSIONS:
             face_vectors = FACE_ANALYZER.vectorize_photo(document["path"])
             if face_vectors:
-                output_document[FACE_VECTOR_FIELD_NAME] = [{"name": "UNKOWN_FACE", "vector": v.tolist()} for v in face_vectors]
+                output_document[FACE_VECTOR_FIELD_NAME] = [{"name": "UNKOWN_FACE", "vector": v} for v in face_vectors]
         # extract text using TIKA
         tika_output = parser.from_file(document["path"], requestOptions={"headers": {"X-Tika-OCRLanguage": "+".join(languages)}})
         content = tika_output["content"]
